<?php
// if ( is_plugin_active( 'advanced-custom-fields/acf.php' ) || is_plugin_active( 'advanced-custom-fields-pro/acf.php' ) ) {
//     // ACF or ACF Pro is activated
//     add_action( 'rest_api_init', 'custom_acf_options_endpoints' );
// }
// // Register custom REST API endpoints
// function custom_acf_options_endpoints() {
//     // Endpoint to get all ACF Options Pages
//     register_rest_route( 'wp/v2', '/acf-options', array(
//         'methods'  => 'GET',
//         'callback' => 'get_all_acf_options_pages',
//     ) );

//     // Endpoint to get all data of a particular ACF Options Page
//     register_rest_route( 'wp/v2', '/acf-options/(?P<page_name>[a-zA-Z0-9-]+)', array(
//         'methods'  => 'GET',
//         'callback' => 'get_all_data_of_acf_options_page',
//     ) );
// }
// // Callback function to get all ACF Options Pages
// function get_all_acf_options_pages() {
//     $options_pages = acf_get_options_pages();
//     return rest_ensure_response( $options_pages );
// }
// // Callback function to get all data of a particular ACF Options Page
// function get_all_data_of_acf_options_page( $request ) {
//     $options_page_data = get_fields( 'options' );
// 	$options_pages = acf_get_options_pages();
// 	if (isset($options_pages[$request['page_name']])) {
//         if (isset($request['field_name'] )) {
//             $field_name = $request['field_name'];
//             if (isset($options_page_data[ $field_name ])) {
//                 return rest_ensure_response($options_page_data[ $field_name ]);
//             }
//             else{
//                 return new WP_Error( 'not_found', 'Field not found', array( 'status' => 404 ) );
//             }
//         } else {
//             return rest_ensure_response( $options_page_data );
//         }
//     }
//     else{
// 		return new WP_Error( 'not_found', 'Option page not found', array( 'status' => 404 ) );
// 	}
// }




/** All slugs*/
// Register a custom REST API endpoint
add_action('rest_api_init', function () {
    register_rest_route('wp/v2', '/content-urls', array(
        'methods' => 'GET',
        'callback' => 'get_all_content_urls_api',
        'permission_callback' => '__return_true', // Set appropriate permissions here
    ));
});

function get_all_content_urls_api() {
    // Initialize an empty array to store details
    $all_details = array();

    // Get home page and blog page IDs
    $home_page_id = get_option('page_on_front');
    $blog_page_id = get_option('page_for_posts');

    // Get all public post types (including custom post types)
    $post_types = get_post_types(array('public' => true), 'names');

    // Loop through each post type
    foreach ($post_types as $post_type) {
        // Get all posts of the current post type
        $posts = get_posts(array(
            'post_type'      => $post_type,
            'post_status'    => 'publish',
            'posts_per_page' => -1,
            'exclude'        => array($home_page_id, $blog_page_id) // Exclude home and blog pages
        ));
        
        // Loop through each post and get its details
        foreach ($posts as $post) {
            // Get the post template
            $template = get_page_template_slug($post->ID);
            if (empty($template)) {
                $template = 'default';
            }

            // Get parent page slug and full path name
            $parent_slug = '';
            if ($post->post_parent) {
                $parent_slug = get_post_field('post_name', $post->post_parent);
            }

            $path_name = build_full_path($post->ID);

            $all_details[] = array(
                'id'          => $post->ID,
                'title'       => $post->post_title,
                'slug'        => $post->post_name,
                'parent_slug' => $parent_slug,
                'template'    => $template,
                'type'        => $post->post_type,
                'path_name'   => $path_name
            );
        }
    }

    // Get home page details
    if ($home_page_id) {
        $home_page = get_post($home_page_id); // Retrieve the home page post object
        $home_page_template = get_page_template_slug($home_page_id);
        if (empty($home_page_template)) {
            $home_page_template = 'default';
        }

        // Get parent page slug and full path name for home page
        $home_parent_slug = '';
        if ($home_page->post_parent) {
            $home_parent_slug = get_post_field('post_name', $home_page->post_parent);
        }

        $home_path_name = build_full_path($home_page_id);

        $all_details[] = array(
            'id'          => $home_page_id,
            'title'       => $home_page->post_title,
            'slug'        => $home_page->post_name,
            'parent_slug' => $home_parent_slug,
            'template'    => $home_page_template,
            'type'        => 'home_page',
            'path_name'   => $home_path_name
        );
    }

    // Get blog page details
    if ($blog_page_id) {
        $blog_page = get_post($blog_page_id); // Retrieve the blog page post object
        $blog_page_template = get_page_template_slug($blog_page_id);
        if (empty($blog_page_template)) {
            $blog_page_template = 'default';
        }

        // Get parent page slug and full path name for blog page
        $blog_parent_slug = '';
        if ($blog_page->post_parent) {
            $blog_parent_slug = get_post_field('post_name', $blog_page->post_parent);
        }

        $blog_path_name = build_full_path($blog_page_id);

        $all_details[] = array(
            'id'          => $blog_page_id,
            'title'       => $blog_page->post_title,
            'slug'        => $blog_page->post_name,
            'parent_slug' => $blog_parent_slug,
            'template'    => $blog_page_template,
            'type'        => 'blog_page',
            'path_name'   => $blog_path_name
        );
    }

    return new WP_REST_Response($all_details, 200);
}

function build_full_path($post_id) {
    $path = array();
    while ($post_id) {
        $post = get_post($post_id);
        array_unshift($path, $post->post_name);
        $post_id = $post->post_parent;
    }
    return implode('/', $path);
}




/**Testing */
// Hook into the REST API initialization action
add_action('rest_api_init', function () {
    // Register the route for retrieving all ACF options page field groups
    register_rest_route('wp/v2', '/acf-options', array(
        'methods' => 'GET',
        'callback' => 'acf_options_callback',
        'permission_callback' => '__return_true', // Set appropriate permissions here
    ));

    // Register the route for retrieving fields of a specific group by group key
    register_rest_route('wp/v2', '/acf-options/(?P<group_key>[\w-]+)', array(
        'methods' => 'GET',
        'callback' => 'acf_options_group_callback',
        'permission_callback' => '__return_true', // Set appropriate permissions here
    ));

    // Register the route for retrieving a specific field value by field name and group key
    register_rest_route('wp/v2', '/acf-options/(?P<group_key>[\w-]+)/(?P<field_name>[\w-]+)', array(
        'methods' => 'GET',
        'callback' => 'acf_options_field_callback',
        'permission_callback' => '__return_true', // Set appropriate permissions here
    ));
});

/**
 * Callback function to retrieve all ACF options page field groups
 */
function acf_options_callback() {
    $field_groups = acf_get_field_groups(array(
        'options_page' => true,
    ));

    if ($field_groups) {
        $all_details = [];
        foreach ($field_groups as $field_group) {
            $all_details[] = array(
                'id'    => $field_group['ID'],
                'key'   => $field_group['key'],
                'title' => $field_group['title'],
            );
        }
        return new WP_REST_Response($all_details, 200);
    } else {
        return new WP_REST_Response(array('message' => 'No ACF options page field groups found.'), 404);
    }
}

/**
 * Callback function to retrieve all fields and their values for a specific group by group key
 */
function acf_options_group_callback($data) {
    $group_key = $data['group_key'];
    $field_group = acf_get_field_group($group_key);

    if ($field_group) {
        $fields = acf_get_fields($group_key);

        if ($fields) {
            $all_details = [];
            foreach ($fields as $field) {
                if (isset($field['name']) && !empty($field['name'])) {
                    $field_value = get_field($field['name'], 'option');
                    if ($field_value !== false) {
                        $all_details[$field['name']] = $field_value;
                    }
                }
            }
            return new WP_REST_Response($all_details, 200);
        } else {
            return new WP_REST_Response(array('message' => 'No ACF fields found for the specified group key.'), 404);
        }
    } else {
        return new WP_REST_Response(array('message' => 'ACF field group not found for the specified group key.'), 404);
    }
}

/**
 * Callback function to retrieve the value of a specific field by field name and group key
 */
function acf_options_field_callback($data) {
    $field_name = $data['field_name'];

    if ($field_name) {
        $field_value = get_field($field_name, 'option');
        return new WP_REST_Response($field_value, 200);
    } else {
        return new WP_REST_Response(array('message' => 'No ACF field found for the specified field name.'), 404);
    }
}