<?php
require_once ABSPATH . 'wp-content/plugins/advanced-custom-fields-pro/includes/fields/class-acf-field.php';

// Check if the ACF plugin is active
if (class_exists('acf_field')) {
class ACF_Field_Variation_Mode extends acf_field {

    function __construct( $settings ) {
        $this->name = 'variation_mode';
        $this->label = __('Variation Mode', 'acf');
        $this->category = 'choice';
        $this->defaults = array(
            'variations' => array(),
            'modes' => array('dark', 'light'),
        );
        $this->settings = $settings;
        parent::__construct();
    }

    function render_field( $field ) {
        // Ensure $field['value'] is an array and initialize 'variation' and 'mode' if they don't exist
        $value = is_array($field['value']) ? $field['value'] : array();
        $value['variation'] = isset($value['variation']) ? $value['variation'] : '';
        $value['mode'] = isset($value['mode']) ? $value['mode'] : '';

        echo '<div class="acf-field-variation-mode" data-variations="' . esc_attr(json_encode($field['variations'])) . '">';
        echo '<div class="acf-variation-select">';
        if (!empty($field['variations'])) {
            foreach( $field['variations'] as $variation => $images ) {
                $selected = ($variation == $value['variation']) ? 'selected' : '';
                echo '<label class="' . esc_attr($selected) . '">';
                echo '<input type="radio" name="' . esc_attr($field['name']) . '[variation]" value="' . esc_attr($variation) . '" ' . checked($variation, $value['variation'], false) . ' />';
                echo esc_html(ucfirst($variation));
                echo '</label>';
            }
        }
        echo '</div>';

        echo '<div class="acf-mode-select">';
        foreach ($field['modes'] as $mode) {
            $checked = ($mode == $value['mode']) ? 'checked' : '';
            echo '<label class="' . esc_attr($checked) . '">';
            echo '<input type="radio" name="' . esc_attr($field['name']) . '[mode]" value="' . esc_attr($mode) . '" ' . checked($mode, $value['mode'], false) . ' />';
            echo esc_html(ucfirst($mode));
            echo '</label>';
        }
        echo '</div>';

        echo '<div class="acf-preview">';
        if (!empty($value['variation']) && !empty($value['mode'])) {
            $preview_image = isset($field['variations'][$value['variation']][$value['mode']]) ? $field['variations'][$value['variation']][$value['mode']] : '';
            if ($preview_image) {
                $preview_image = get_template_directory_uri() .'/preview-images/' . $preview_image;
                echo '<img src="' . esc_url($preview_image) . '" alt="' . esc_attr($value['variation'] . ' ' . $value['mode']) . ' preview" />';
            }
            else{
                echo '<p>Image preview not available</p>';
            }
        }
        echo '</div>';
        echo '</div>';
    }

    function input_admin_enqueue_scripts() {
        $dir = $this->settings['url'];
        wp_enqueue_style('acf-input-variation-mode', "{$dir}css/input.css", array('acf-input'), $this->settings['version']);
        wp_enqueue_script('acf-input-variation-mode', "{$dir}js/input.js", array('acf-input'), $this->settings['version']);
        // Pass theme directory URL to input.js
        wp_localize_script('acf-input-variation-mode', 'themeData', array(
            'themeDir' => get_template_directory_uri() .'/preview-images/'
        ));
    }

    function render_field_settings( $field ) {
        $variations = isset($field['variations']) ? json_encode($field['variations'], JSON_PRETTY_PRINT) : '{}';
        acf_render_field_setting( $field, array(
            'label'         => __('Variations','acf'),
            'instructions'  => __('Add variations and their preview images as JSON. For example: {"variation1": {"dark": "image1.jpg", "light": "image2.jpg"}}','acf'),
            'type'          => 'textarea',
            'name'          => 'variations',
            'value'         => $variations
        ));

        $modes = isset($field['modes']) && !empty($field['modes']) ? implode("\n", $field['modes']) : "dark\nlight";
        acf_render_field_setting( $field, array(
            'label'         => __('Modes','acf'),
            'instructions'  => __('Add each mode on a new line.','acf'),
            'type'          => 'textarea',
            'name'          => 'modes',
            'value'         => $modes
        ));
    }

    function load_field( $field ) {
        if (!empty($field['variations']) && is_string($field['variations'])) {
            $field['variations'] = json_decode($field['variations'], true);
        }

        if (!empty($field['modes']) && is_string($field['modes'])) {
            $field['modes'] = explode("\n", str_replace("\r", "", $field['modes']));
        }

        return $field;
    }
    
}
}
