<?php
/**
 * hvac functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package hvac
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function hvac_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on hvac, use a find and replace
		* to change 'hvac' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'hvac', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'primary-menu' => esc_html__( 'Primary', 'hvac' ),
			'footer-menu' => esc_html__( 'Footer', 'hvac' ),
			'footer-services-menu' => esc_html__( 'Footer Services', 'hvac' ),
			'policy-menu' => esc_html__( 'Policy Menu', 'hvac' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'hvac_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'hvac_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function hvac_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'hvac_content_width', 640 );
}
add_action( 'after_setup_theme', 'hvac_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function hvac_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'hvac' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'hvac' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'hvac_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function hvac_scripts() {
	wp_enqueue_style( 'hvac-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'hvac-style', 'rtl', 'replace' );

	wp_enqueue_script( 'hvac-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'hvac_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// Allow non-logged-in users to access REST API endpoints
function allow_rest_api_access_for_all( $permission ) {
    // Return true to allow access for all users
    return true;
}
// add_filter( 'rest_authentication_errors', 'allow_rest_api_access_for_all' );


/**
 * Bypass Force Login to allow for REST API exceptions.
 *
 * @param mixed $result WP_Error if authentication error, null if authentication
 *                      method wasn't used, true if authentication succeeded.
 */
function my_forcelogin_bypass_rest_api( $result ) {

  // Skip if request is authenticated
  if ( ! empty( $result ) ) {
    return $result;
  }

  // Allow specific endpoint public access
  //if ( $endpoint ) {
  //  return true;
  //}

  return $result;
}
// add_filter( 'rest_authentication_errors', 'my_forcelogin_bypass_rest_api', 20 );


add_filter( 'acf/settings/rest_api_format', function () {
    return 'standard';
} );


// function populate_acf_dropdown_with_theme_options($field) {
//     // Get the field object for the 'theme_options' group
//     $theme_options = get_field_object('theme_options', 'option');
//     // Check if the field object and its value exist
//     if ($theme_options && !empty($theme_options['value']['theme_color_options'])) {
//         $theme_options_values = $theme_options['value']['theme_color_options'];

//         // Loop through the theme_options values and populate the dropdown
//         foreach ($theme_options_values as $key => $value) {
//             // Replace underscores with spaces and capitalize each word for label
//             $label = ucwords(str_replace('_', ' ', $key));

//             // Generate HTML for color swatch within a span tag
//             // $color_swatch = '<span class="color-swatch" style="background-color: ' . $value . ';"></span>';

//             // Add choice with label and color swatch HTML, including a data attribute for color
//             $field['choices'][$value] = $label .'('.$value.')';
//         }
//     }

//     // Add "Add New" option
//     $field['choices']['custom_color'] = 'Custom Color';
//     return $field;
// }
// add_filter('acf/load_field/name=section_background_color', 'populate_acf_dropdown_with_theme_options');
function populate_acf_dropdown_with_theme_options($field) {
    // Clear existing choices to avoid duplicates
    $field['choices'] = array();

    // Get the field object for the 'theme_options' group
    $theme_options = get_field('theme_options', 'option');
    // Check if the field object and its value exist
    if ($theme_options && !empty($theme_options['theme_color_options'])) {
        $theme_options_values = $theme_options['theme_color_options'];

        // Loop through the theme_options values and populate the dropdown
        foreach ($theme_options_values as $key => $value) {
            // Replace underscores with spaces and capitalize each word for label
            $label = ucwords(str_replace('_', ' ', $key));
			// echo '<pre>'; print_r( $key ); echo '</pre>';
            // Add choice with label and value
            $field['choices'][$key] = $label . ' (' . $value . ')';
        }
    }

    // Add "Custom Color" option
    $field['choices']['custom_color'] = 'Custom Color';

    return $field;
}
add_filter('acf/load_field/name=section_background_color', 'populate_acf_dropdown_with_theme_options');

// Hook into save_post to update the dropdown dynamically when theme_options are saved
function refresh_acf_dropdown_on_theme_options_save($post_id) {
    // Check if this is the options page and theme_options field group
    if ($post_id === 'options') {
        $theme_options = get_field('theme_options', 'option');
        if ($theme_options) {
            // Clear any cache or perform an action to refresh the field values
            delete_transient('acf_field_section_background_color_choices');
        }
    }
}
add_action('acf/save_post', 'refresh_acf_dropdown_on_theme_options_save', 20);

// Ensure the transient is cleared when the theme options are saved
add_action('acf/save_post', function($post_id) {
    if ($post_id === 'options') {
        delete_transient('acf_field_section_background_color_choices');
    }
}, 20);






function my_acf_format_value( $value, $post_id, $field ) {
    // Check if value is set and not empty
    if( $value ) {
        // Remove <p> and <br> tags
        $value = wpautop($value); // Initially apply wpautop to format correctly
        $value = str_replace(array('<p>', '</p>'), '', $value); // Remove <p> tags
        $value = str_replace('<br />', '', $value); // Remove <br /> tags if needed
    }

    return $value;
}

// Add this filter for specific fields by field name
add_filter('acf/format_value/name=description', 'my_acf_format_value', 10, 3);

// Alternatively, add this filter for all WYSIWYG fields
// add_filter('acf/format_value/type=wysiwyg', 'my_acf_format_value', 10, 3);